@@ -1,7 +1,6 @@
 summary.limitmeta <- function(object, ...){
-  
-  if (!inherits(object, "limitmeta"))
-    stop("Argument 'object' must be an object of class \"limitmeta\"")
+
+  meta:::chkclass(object, "limitmeta")
   
   res <- object
   class(res) <- c("summary.limitmeta", "limitmeta")
